Package: MaxMC
Type: Package
Title: Maximized Monte Carlo
Date: 2024-09-29
Version: 0.1.2
Authors@R: c(person("Julien", "Neves", email = "jmn252@cornell.edu", role = c("aut")), person("Jean-Marie", "Dufour", email = "jean-marie.dufour@mcgill.ca", role = c("aut", "ths")), person("Gabriel", "Rodriguez-Rondon", email = "gabriel.rodriguezrondon@mail.mcgill.ca", role = c("cre")) )
Maintainer: Gabriel Rodriguez-Rondon <gabriel.rodriguezrondon@mail.mcgill.ca>
Description: An implementation of the Monte Carlo techniques described in details by Dufour (2006) <doi:10.1016/j.jeconom.2005.06.007> and Dufour and Khalaf (2007) <doi:10.1002/9780470996249.ch24>. The two main features available are the Monte Carlo method with tie-breaker, mc(), for discrete statistics, and the Maximized Monte Carlo, mmc(), for statistics with nuisance parameters.
License: GPL (>= 3)
RoxygenNote: 7.3.1
Encoding: UTF-8
URL: https://github.com/julienneves/MaxMC
Suggests: fUnitRoots, microbenchmark, boot, MASS, knitr, rmarkdown
Imports: GenSA, pso, GA, NMOF, scales, stats, graphics, utils,
NeedsCompilation: no
Packaged: 2024-10-01 12:22:57 UTC; gabrielrodriguez
Author: Julien Neves [aut],
  Jean-Marie Dufour [aut, ths],
  Gabriel Rodriguez-Rondon [cre]
Repository: CRAN
Date/Publication: 2024-10-02 16:40:06 UTC
Built: R 4.6.0; ; 2026-04-27 18:14:13 UTC; unix
