# Select method
method = "GenSA"

# Select control to modify and store in a list
control = list(maxit = 100)

# Get all controls for the method specify
MaxMC:::get_control(method = method, control = control)

